interface FormatOptions {
    indent?: {
        style: string;
        base: number;
        adjustMultilineComment: boolean;
    };
    newline?: '\n';
    space?: ' ';
    json?: boolean;
    renumber?: boolean;
    hexadecimal?: boolean;
    quotes?: 'single' | 'double';
    escapeless?: boolean;
    compact?: boolean;
    parentheses?: boolean;
    semicolons?: boolean;
    safeConcatenation?: boolean;
    preserveBlankLines?: boolean;
}
interface MozillaOptions {
    comprehensionExpressionStartsWithAssignment: false;
    starlessGenerator: false;
}
interface GenerateOptions {
    comment?: boolean;
    file?: string;
    format?: FormatOptions;
    moz?: MozillaOptions;
    sourceContent?: string;
    sourceMap?: null;
    sourceMapRoot?: null;
    sourceMapWithCode?: false;
    directive?: false;
    raw?: true;
    verbatim?: string | null;
    sourceCode?: null;
}

interface ParseOptions {
    comment?: boolean;
    attachComment?: boolean;
    sourceType?: 'module' | 'script';
    jsx?: boolean;
    /**
     * Determines whether the parser reports range: [start: number, end: number].
     */
    range?: boolean;
    /**
     * Determines whether the parser reports loc: {start:{line:number;column:number}; end:{line:number;column:number}}
     */
    loc?: boolean;
    tokens?: boolean;
    tolerant?: boolean;
    source?: string;
}

/**
 * Provides the MathScript module
 */
/**
 * Determines the transformation action for operators.
 */
interface OperatorTransform {
    /**
     * The nature of the transformation.
     *
     * 'rename' replaces the name of the operator with the value property.
     *
     * 'function' replaces the operator with a function call with a name given by the value property.
     *
     * 'error' causes an exception to be raised if the operator is detected. The value property becomes the error message.
     */
    kind: 'rename' | 'function' | 'error';
    /**
     * The transformed value. How it is used depends on the kind property.
     *
     * 'rename': value is treated as the new operator name.
     * 'function': value is treated as the new function name.
     * 'error': value is treated as the error message.
     */
    value: string;
}
/**
 * The combined parsing and transpilation customization.
 * These properties affect the parsing and AST transformations before code generation.
 */
interface TranspileOptions extends ParseOptions {
    /**
     * Specifies the timeout value in milliseconds if the code has loop checks inserted.
     */
    timeout?: number;
    /**
     * Used to determine whether timeout checks will be added to the code to prevent infinite loops.
     */
    noLoopCheck?: boolean;
    /**
     * The namespace qualification to use for replacements of operators with functions.
     */
    namespace?: string;
    /**
     * The replacements of binary operators that will be made.
     * The name key is used to match the operator symbol.
     * The mapped transform is used to specify the action to be performed.
     */
    binOp?: {
        [name: string]: OperatorTransform;
    };
    /**
     * The replacements of unary operators that will be made.
     * The name key is used to match the operator symbol.
     * The mapped transform is used to specify the action to be performed.
     */
    unaryOp?: {
        [name: string]: OperatorTransform;
    };
}
/**
 * Transpiles JavaScript Expression syntax to "MathScript", a similar syntax to JavaScript but perhaps with different operator symbols.
 * Examples of MathScript(s) include Algebrite (a symbolic algebra library), and JessieCode (a scripting language for JSXGraph).
 * Typical use cases include renaming operators, converting operators to function calls, and rejecting operators as syntax errors.
 * @param code The source code to be transpiled.
 * @param transpileOptions The options for both parsing and mutation.
 * @param generateOptions The options for code generation.
 */
declare function jsToMathScript(code: string, transpileOptions?: TranspileOptions, generateOptions?: GenerateOptions): {
    code: string;
};

export { FormatOptions, GenerateOptions, MozillaOptions, OperatorTransform, TranspileOptions, jsToMathScript };
